@@ -1,7 +1,7 @@
 #ifndef _SYMBOL_H
 #define _SYMBOL_H
 
-typedef unsigned char *symbol_t;
+typedef char *symbol_t;
 
 extern symbol_t symbol(const char *);
 extern int symcmp(symbol_t, symbol_t);
